@@ -1,10 +1,10 @@
 #================================ Syslog.pm ==================================
 # Filename:             Syslog.pm
-# Description:          Syslog logger delegate
+# Description:          Syslog logger delegate.
 # Original Author:      Dale M. Amon
 # Revised by:           $Author: amon $ 
-# Date:                 $Date: 2008-07-24 21:17:24 $ 
-# Version:              $Revision: 1.7 $
+# Date:                 $Date: 2008-08-28 23:20:19 $ 
+# Version:              $Revision: 1.9 $
 # License:		LGPL 2.1, Perl Artistic or BSD
 #
 #=============================================================================
@@ -57,7 +57,7 @@ sub _connect ($) {
 
 =head1 NAME
 
-Fault::Delegate::Syslog - Syslog delegate
+ Fault::Delegate::Syslog - Syslog delegate.
 
 =head1 SYNOPSIS
 
@@ -128,7 +128,7 @@ so that it will appear in the log like this:
 
 =head1 Private Class Methods
 
-None.
+ None.
 
 =head1 Private Instance Methods
 
@@ -148,6 +148,10 @@ the Fault:Delegate log and test methods.
 Local warning messages are issued if the sys logger cannot be reached or has 
 any problems whatever. 
 
+=head1 KNOWN BUGS
+
+ See TODO.
+
 =head1 SEE ALSO
 
 Fault::Logger, Fault::Delegate, Fault::Msg, Sys::Syslog
@@ -163,6 +167,12 @@ Dale Amon <amon@vnl.com>
 #                                CVS HISTORY
 #=============================================================================
 # $Log: Syslog.pm,v $
+# Revision 1.9  2008-08-28 23:20:19  amon
+# perldoc section regularization.
+#
+# Revision 1.8  2008-08-17 21:56:37  amon
+# Make all titles fit CPAN standard.
+#
 # Revision 1.7  2008-07-24 21:17:24  amon
 # Moved all todo notes to elsewhere; made Stderr the default delegate instead of Stdout.
 #
